@@ -8,7 +8,6 @@
 #include <QCommandLineParser>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
-#include <QLoggingCategory>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
 #include <QSessionManager>
@@ -17,53 +16,13 @@
 
 #include <KAboutData>
 #include <KDBusService>
-#include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
 #include <KWindowSystem>
 
+#include "CommandLineArguments.h"
 #include "Configuration.h"
 #include "ToolsModel.h"
 
-static QLoggingCategory::CategoryFilter oldCategoryFilter;
-
-// Qt 5.14 introduces a new syntax for connections
-// framework code can't port away due to needing Qt5.12
-// this filters out the warnings
-// Remove this once we depend on Qt5.15 in frameworks
-void filterConnectionSyntaxWarning(QLoggingCategory *category)
-{
-    if (qstrcmp(category->categoryName(), "qt.qml.connections") == 0) {
-        category->setEnabled(QtWarningMsg, false);
-    } else if (oldCategoryFilter) {
-        oldCategoryFilter(category);
-    }
-}
-
-class CommandLineArguments : public QObject
-{
-    Q_OBJECT
-    Q_PROPERTY(QString pageId MEMBER m_pageId CONSTANT)
-    Q_PROPERTY(QString pageName MEMBER m_pageName CONSTANT)
-    Q_PROPERTY(QVariant aboutData READ aboutData CONSTANT)
-
-public:
-    CommandLineArguments(QCommandLineParser &parser)
-        : QObject()
-        , m_pageId(parser.value(QStringLiteral("page-id")))
-        , m_pageName(parser.value(QStringLiteral("page-name")))
-    {
-    }
-
-    QVariant aboutData() const
-    {
-        return QVariant::fromValue(KAboutData::applicationData());
-    }
-
-private:
-    QString m_pageId;
-    QString m_pageName;
-};
-
 class SessionManager : public QObject
 {
     Q_OBJECT
@@ -97,14 +56,9 @@ int main(int argc, char **argv)
     QSurfaceFormat::setDefaultFormat(format);
 
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("utilities-system-monitor")));
 
-    oldCategoryFilter = QLoggingCategory::installFilter(filterConnectionSyntaxWarning);
-
-    KLocalizedString::setApplicationDomain("plasma-systemmonitor");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("plasma-systemmonitor"));
 
     KAboutData aboutData{/* componentName */ QStringLiteral("plasma-systemmonitor"),
                          /* displayName */ i18n("System Monitor"),
@@ -132,24 +86,19 @@ int main(int argc, char **argv)
 
     KDBusService service(KDBusService::Unique);
 
-    QCommandLineParser parser;
-    aboutData.setupCommandLine(&parser);
-    parser.addOption({QStringLiteral("page-id"), QStringLiteral("Start with the specified page ID shown"), QStringLiteral("page-id")});
-    parser.addOption({QStringLiteral("page-name"), QStringLiteral("Start with the specified page name shown"), QStringLiteral("page-name")});
-    parser.process(app);
-    aboutData.processCommandLine(&parser);
+    auto parser = std::make_shared<QCommandLineParser>();
+    aboutData.setupCommandLine(parser.get());
+    parser->addOption({QStringLiteral("page-id"), QStringLiteral("Start with the specified page ID shown"), QStringLiteral("page-id")});
+    parser->addOption({QStringLiteral("page-name"), QStringLiteral("Start with the specified page name shown"), QStringLiteral("page-name")});
+    parser->process(app);
+    aboutData.processCommandLine(parser.get());
+    CommandLineArguments::setCommandLineParser(parser);
 
-    qmlRegisterAnonymousType<QAbstractItemModel>("org.kde.systemmonitor", 1);
-    qmlRegisterType<ToolsModel>("org.kde.systemmonitor", 1, 0, "ToolsModel");
-    qmlRegisterType<Configuration>("org.kde.systemmonitor", 1, 0, "Configuration");
-    qmlRegisterSingletonType<CommandLineArguments>("org.kde.systemmonitor", 1, 0, "CommandLineArguments", [&parser](QQmlEngine *, QJSEngine *) {
-        return new CommandLineArguments{parser};
-    });
     auto sessionManager = new SessionManager(&app);
 
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
+    engine.loadFromModule("org.kde.systemmonitor", "Main");
 
     QObject::connect(&service, &KDBusService::activateRequested, &engine, []() {
         if (!qApp->topLevelWindows().isEmpty()) {
